@@ -1,12 +1,9 @@
 {-# LANGUAGE CPP         #-}
-#if __GLASGOW_HASKELL__ >= 704
 {-# LANGUAGE Safe        #-}
-#elif __GLASGOW_HASKELL__ >= 702
-{-# LANGUAGE Trustworthy #-}
-#endif
 module Data.GADT.Compare (
     -- * Equality
     GEq (..),
+    defaultGeq,
     defaultEq,
     defaultNeq,
     -- * Total order comparison
