@@ -1,30 +1,24 @@
-{-# LANGUAGE CPP         #-}
-{-# LANGUAGE GADTs       #-}
-#if __GLASGOW_HASKELL__ >= 706
-{-# LANGUAGE PolyKinds   #-}
-#endif
+{-# LANGUAGE CPP                      #-}
+{-# LANGUAGE GADTs                    #-}
+{-# LANGUAGE PolyKinds                #-}
+{-# LANGUAGE Safe                     #-}
+{-# LANGUAGE TypeOperators            #-}
 #if __GLASGOW_HASKELL__ >= 810
 {-# LANGUAGE StandaloneKindSignatures #-}
 #endif
-#if (__GLASGOW_HASKELL__ >= 704 && __GLASGOW_HASKELL__ < 707) || __GLASGOW_HASKELL__ >= 801
-{-# LANGUAGE Safe        #-}
-#elif __GLASGOW_HASKELL__ >= 702
-{-# LANGUAGE Trustworthy #-}
-#endif
 module Data.GADT.DeepSeq (
     GNFData (..),
     ) where
 
 import Data.Functor.Product (Product (..))
 import Data.Functor.Sum     (Sum (..))
-import Data.Type.Equality   ((:~:) (..))
+import Data.Type.Equality   ((:~:) (..), (:~~:) (..))
+import GHC.Generics         ((:*:) (..), (:+:) (..))
 
-#if MIN_VERSION_base(4,10,0)
-import qualified Type.Reflection    as TR
-#endif
+import qualified Type.Reflection as TR
 
 #if __GLASGOW_HASKELL__ >= 810
-import Data.Kind (Type, Constraint)
+import Data.Kind (Constraint, Type)
 #endif
 
 #if __GLASGOW_HASKELL__ >= 810
@@ -41,12 +35,21 @@ instance (GNFData a, GNFData b) => GNFData (Sum a b) where
     grnf (InL x) = grnf x
     grnf (InR y) = grnf y
 
+instance (GNFData a, GNFData b) => GNFData (a :*: b) where
+    grnf (a :*: b) = grnf a `seq` grnf b
+
+instance (GNFData a, GNFData b) => GNFData (a :+: b) where
+    grnf (L1 x) = grnf x
+    grnf (R1 y) = grnf y
+
 -- | @since 1.0.3
 instance GNFData ((:~:) a) where
     grnf Refl = ()
 
-#if MIN_VERSION_base(4,10,0)
+-- | @since 1.0.4
+instance GNFData ((:~~:) a) where
+    grnf HRefl = ()
+
 -- | @since 1.0.3
 instance GNFData TR.TypeRep where
     grnf = TR.rnfTypeRep
-#endif
