@@ -1,9 +1,5 @@
 {-# LANGUAGE CPP         #-}
-#if __GLASGOW_HASKELL__ >= 704
 {-# LANGUAGE Safe        #-}
-#elif __GLASGOW_HASKELL__ >= 702
-{-# LANGUAGE Trustworthy #-}
-#endif
 module Data.Some.Church (
     Some(..),
     mkSome,
